SystemOrganization addCategory: #ConfigurationOfCodeSight!

Object subclass: #ConfigurationOfCodeSight
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfCodeSight'!

!ConfigurationOfCodeSight class methodsFor: 'private' stamp: 'bs 10/6/2010 13:57:33.986'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfCodeSight class methodsFor: 'private' stamp: 'bs 10/6/2010 13:57:34.003'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfCodeSight class methodsFor: 'metacello tool support' stamp: 'bs 10/6/2010 13:57:34.022'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfCodeSight class methodsFor: 'metacello tool support' stamp: 'bs 10/6/2010 13:57:34.037'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfCodeSight class methodsFor: 'loading' stamp: 'mt 5/9/2011 13:23:59.155'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	"^(self project version: #stable) load"
	Error signal: 'There is no stable version yet. Use #loadSnapshot instead.'.! !

!ConfigurationOfCodeSight class methodsFor: 'loading' stamp: 'mt 5/9/2011 13:23:20.702'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfCodeSight class methodsFor: 'loading' stamp: 'mt 5/9/2011 13:23:14.991'!
loadSnapshot
	"Load the latest snapshot which may be buggy but is not equivalent with the current head #development version."

	"self loadSnapshot"

	<apiDocumentation>
	^(self project version: #snapshot) load! !

!ConfigurationOfCodeSight class methodsFor: 'metacello tool support' stamp: 'bs 10/6/2010 13:57:34.053'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfCodeSight class methodsFor: 'accessing' stamp: 'bs 10/6/2010 13:57:34.083'!
project

	^self new project! !

!ConfigurationOfCodeSight class methodsFor: 'unloading Metacello' stamp: 'bs 10/6/2010 13:57:34.097'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfCodeSight methodsFor: 'baselines' stamp: 'mt 5/9/2011 14:16:12.542'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/CodeSight'. 
		
		spec project: 'OmniBrowser' with: [
			spec
				className: 'ConfigurationOfOmniBrowser';
				repository: 'http://www.squeaksource.com/MetacelloRepository';
				loads: #( Dev )].
		
		spec project: 'RefactoringBrowser' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					loads: #(Core)].
		
		spec project: 'OSProcess' with: [
			spec
				className: 'ConfigurationOfOSProcess';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].
			
		spec project: 'SwaUtil' with: [
			spec
				className: 'ConfigurationOfSwaUtil';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec
			package: 'MethodWrappers' with: [spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'];
			
			package: 'SWAOBExtensions' with: [spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities';
				requires: #( 'OmniBrowser' )];
			
			package: 'Actors' with: [spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities' ].
		
		spec 
			package: 'Sight-Cst' with: [ 
				spec requires: #( 'OSProcess' 'MethodWrappers' 'Actors' 'SwaUtil' RefactoringBrowser ) ];
			package: 'Sight-Events';
			package: 'Sight-Fixed';
			package: 'Sight-TestBed';
			package: 'Sight-Tracing';
			package: 'SightL' with: [ 
				spec requires: #( 'MethodWrappers' 'Actors' 'SwaUtil' 'Sight-Cst' ) ];
			package: 'Sight-Path' with: [
				spec requires: #( 'Sight-Cst' 'SightL' )];
			package: 'Sight-OB' with: [
				spec requires: #( OmniBrowser 'SWAOBExtensions' )].
		
		spec
			group: 'default' with: #(core);
			group: 'core' with: #('Sight-Cst' 'Sight-Tracing' 'Sight-Events' 'Sight-Fixed' 'Sight-TestBed');
			group: 'ob' with: #(core 'Sight-OB');
			group: 'path' with: #(core 'SightL' 'Sight-Path') ].! !

!ConfigurationOfCodeSight methodsFor: 'symbolic versions' stamp: 'mt 5/9/2011 13:51:27.159'!
development: spec
	<symbolicVersion: #development>
	
	spec for: #'squeak4.2.x' version: '1.0'.! !

!ConfigurationOfCodeSight methodsFor: 'accessing' stamp: 'bs 10/6/2010 13:57:33.97'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfCodeSight methodsFor: 'symbolic versions' stamp: 'mt 6/30/2011 14:06:56.878'!
snapshot: spec
	<symbolicVersion: #snapshot>
	
	spec for: #'common' version: '1.0-snapshot-110630'.! !

!ConfigurationOfCodeSight methodsFor: 'versions' stamp: 'mt 5/9/2011 15:48:57.371'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >
        
	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Bastian Steinert'.
		
		spec
			project: 'OmniBrowser' with: '1.2';
			project: 'OSProcess' with: '4.4.0';
			project: 'RefactoringBrowser' with: #stable].! !

!ConfigurationOfCodeSight methodsFor: 'versions' stamp: 'mt 5/9/2011 15:48:50.201'!
version100snapshot110509: spec 
	<version: '1.0-snapshot-110509' imports: #('1.0-baseline') >
        
	spec for: #common do: [
		spec blessing: #snapshot.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'OmniBrowser' with: '1.2';
			project: 'OSProcess' with: '4.4.0';
			project: 'RefactoringBrowser' with: '1.6';
			project: 'SwaUtil' with: '1.1';
			package: 'MethodWrappers' with: 'MethodWrappers-bs.19';
			package: 'SWAOBExtensions' with: 'SWAOBExtensions-test.5';
			package: 'Actors' with: 'Actors-bs.4';
			
			package: 'Sight-Cst' with: 'Sight-Cst-mt.21';
			package: 'Sight-Tracing' with: 'Sight-Tracing-bs.25';
			package: 'Sight-Events' with: 'Sight-Events-bs.2';
			package: 'Sight-Fixed' with: 'Sight-Fixed-bs.6';
			package: 'Sight-TestBed' with: 'Sight-TestBed-bs.17';
			
			package: 'Sight-OB' with: 'Sight-OB-mt.12';
			package: 'SightL' with: 'SightL-mp.190';
			package: 'Sight-Path' with: 'Sight-Path-bs.6'].! !

!ConfigurationOfCodeSight methodsFor: 'versions' stamp: 'mt 6/30/2011 14:06:44.446'!
version100snapshot110630: spec 
	<version: '1.0-snapshot-110630' imports: #('1.0-baseline') >
        
	spec for: #common do: [
		spec blessing: #snapshot.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'OmniBrowser' with: '1.2';
			project: 'OSProcess' with: '4.4.0';
			project: 'RefactoringBrowser' with: '1.6';
			project: 'SwaUtil' with: '1.1';
			package: 'MethodWrappers' with: 'MethodWrappers-bs.19';
			package: 'SWAOBExtensions' with: 'SWAOBExtensions-test.5';
			package: 'Actors' with: 'Actors-bs.4';
			
			package: 'Sight-Cst' with: 'Sight-Cst-TM.44';
			package: 'Sight-Tracing' with: 'Sight-Tracing-bs.25';
			package: 'Sight-Events' with: 'Sight-Events-bs.2';
			package: 'Sight-Fixed' with: 'Sight-Fixed-bs.6';
			package: 'Sight-TestBed' with: 'Sight-TestBed-bs.17';
			
			package: 'Sight-OB' with: 'Sight-OB-mt.12';
			package: 'SightL' with: 'SightL-mp.190';
			package: 'Sight-Path' with: 'Sight-Path-bs.6'].! !
